@@ -1,19 +1,23 @@
-# Copyright 2018-2023 contributors to the OpenLineage project
+# Copyright 2018-2024 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 from __future__ import annotations
 
 import logging
-from typing import TYPE_CHECKING, TypeVar, Union
+from typing import TYPE_CHECKING, Any, TypeVar
 
 import attr
+from openlineage.client import event_v2
+from openlineage.client.facet import ParentRunFacet
+from openlineage.client.facet_v2 import parent_run
+from openlineage.client.run import DatasetEvent, JobEvent
 from openlineage.client.serde import Serde
 from openlineage.client.transport.transport import Config, Transport
 from openlineage.client.utils import get_only_specified_fields
-from pkg_resources import parse_version
+from packaging.version import Version
 
 if TYPE_CHECKING:
     from confluent_kafka import KafkaError, Message
-    from openlineage.client.run import DatasetEvent, JobEvent, RunEvent
+    from openlineage.client.client import Event
 log = logging.getLogger(__name__)
 
 _T = TypeVar("_T", bound="KafkaConfig")
@@ -28,12 +32,18 @@ class KafkaConfig(Config):
     # Topic on which we should send messages
     topic: str = attr.ib()
 
+    # Explicit key for Kafka producer
+    messageKey: str | None = attr.ib(default=None)  # noqa: N815
+
     # Set to true if Kafka should flush after each event. The process that emits can be killed in
     # some cases - for example in Airflow integration, so flushing is desirable there.
     flush: bool = attr.ib(default=True)
 
     @classmethod
-    def from_dict(cls: type[_T], params: dict[str, str]) -> _T:
+    def from_dict(cls: type[_T], params: dict[str, Any]) -> _T:
+        # alias message_key to messageKey
+        if message_key := params.pop("message_key", None):
+            params["messageKey"] = params.get("messageKey") or message_key
         if "config" not in params:
             msg = "kafka `config` not passed to KafkaConfig"
             raise RuntimeError(msg)
@@ -57,18 +67,74 @@ class KafkaTransport(Transport):
     def __init__(self, config: KafkaConfig) -> None:
         self.topic = config.topic
         self.flush = config.flush
+        self.message_key = config.messageKey
         self.kafka_config = config
         self._is_airflow_sqlalchemy = _check_if_airflow_sqlalchemy_context()
         self.producer = None
         if not self._is_airflow_sqlalchemy:
             self._setup_producer(self.kafka_config.config)
-        log.debug("Constructing openlineage client to send events to topic %s", config.topic)
+        log.debug(
+            "Constructing OpenLineage transport that will send events "
+            "to kafka topic `%s` using the following config: %s",
+            self.topic,
+            self.kafka_config,
+        )
 
-    def emit(self, event: Union[RunEvent, DatasetEvent, JobEvent]) -> None:  # noqa: UP007
+    def _get_message_key(self, event: Event) -> str:
+        if isinstance(event, (DatasetEvent, event_v2.DatasetEvent)):
+            return f"dataset:{event.dataset.namespace}/{event.dataset.name}"
+
+        if isinstance(event, (JobEvent, event_v2.JobEvent)):
+            return f"job:{event.job.namespace}/{event.job.name}"
+
+        run_facets: dict[str, Any] = event.run.facets or {}
+        parent_run_facet: ParentRunFacet | parent_run.ParentRunFacet = run_facets.get(
+            "parent"
+        ) or ParentRunFacet({}, {})
+
+        parent_job_namespace: str | None = None
+        parent_job_name: str | None = None
+        if isinstance(parent_run_facet, parent_run.ParentRunFacet):
+            (
+                parent_job_namespace,
+                parent_job_name,
+            ) = self._get_message_key_args_from_parent_run_facet_v2(parent_run_facet)
+        else:
+            (
+                parent_job_namespace,
+                parent_job_name,
+            ) = self._get_message_key_args_from_parent_run_facet(parent_run_facet)
+
+        if parent_job_namespace and parent_job_name:
+            return f"run:{parent_job_namespace}/{parent_job_name}"
+
+        return f"run:{event.job.namespace}/{event.job.name}"
+
+    def _get_message_key_args_from_parent_run_facet(
+        self,
+        parent_run_facet: ParentRunFacet,
+    ) -> tuple[str | None, str | None]:
+        parent_job_namespace = parent_run_facet.job.get("namespace")
+        parent_job_name = parent_run_facet.job.get("name")
+        return parent_job_namespace, parent_job_name
+
+    def _get_message_key_args_from_parent_run_facet_v2(
+        self,
+        parent_run_facet: parent_run.ParentRunFacet,
+    ) -> tuple[str, str]:
+        parent_job_namespace: str = parent_run_facet.job.namespace
+        parent_job_name: str = parent_run_facet.job.name
+        return parent_job_namespace, parent_job_name
+
+    def emit(self, event: Event) -> None:
         if self._is_airflow_sqlalchemy:
             self._setup_producer(self.kafka_config.config)
+
+        key = self.message_key or self._get_message_key(event)
+
         self.producer.produce(  # type: ignore[attr-defined]
             topic=self.topic,
+            key=key,
             value=Serde.to_json(event).encode("utf-8"),
             on_delivery=on_delivery,
         )
@@ -101,10 +167,10 @@ class KafkaTransport(Transport):
 
 def _check_if_airflow_sqlalchemy_context() -> bool:
     try:
-        from airflow.version import version  # type: ignore[import]
+        from airflow.version import version  # type: ignore[import-not-found]
 
-        parsed_version = parse_version(version)
-        if parse_version("2.3.0") <= parsed_version < parse_version("2.6.0"):
+        parsed_version = Version(version)
+        if Version("2.3.0") <= parsed_version < Version("2.6.0"):
             return True
     except ImportError:
         pass  # we want to leave it to false if airflow import fails
